#
# spec file for package python-djangorestframework-simplejwt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-djangorestframework-simplejwt
Version:        5.3.1
Release:        3.1
Summary:        JSON Web Token authentication for Django REST Framework
License:        MIT
URL:            https://github.com/davesque/django-rest-framework-simplejwt
Source:         https://files.pythonhosted.org/packages/source/d/djangorestframework-simplejwt/djangorestframework_simplejwt-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/jazzband/djangorestframework-simplejwt/pull/769 Fix tests
Patch0:         fix-tests.patch
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module PyJWT}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module djangorestframework}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module python-jose}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyJWT
Requires:       python-djangorestframework
Recommends:     python-cryptography
Recommends:     python-python-jose
BuildArch:      noarch
%python_subpackages

%description
A minimal JSON Web Token authentication plugin for the Django REST Framework.

%prep
%autosetup -p1 -n djangorestframework_simplejwt-%{version}

%build
export LANG=en_US.UTF-8
%pyproject_wheel

%install
export LANG=en_US.UTF-8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%license LICENSE.txt licenses/*
%doc README.rst CHANGELOG.md
%{python_sitelib}/rest_framework_simplejwt
%{python_sitelib}/djangorestframework_simplejwt-%{version}.dist-info

%changelog
* Mon Nov 11 2024 Markéta Machová <mmachova@suse.com>
- Add missing dependency
* Fri Jul 19 2024 Markéta Machová <mmachova@suse.com>
- Add upstream patch fix-tests.patch to fix tests with Django 5
* Mon Jun 24 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch back to PyPi tarball.
- Inject setuptools_scm so we install the correct version number.
- Switch to autosetup macro.
- No more greedy globs in %%files.
* Tue Jun 18 2024 Markéta Machová <mmachova@suse.com>
- Update to 5.3.1
  * Breaking: Set BLACKLIST_AFTER_ROTATION by default to False
  * Remove EOL Python, Django and DRF version support
  * Remove verify from jwt.decode to follow PyJWT v2.2.0
  * Add blacklist view to log out users
  * Add JWKS support
  * Add back support for PyJWT 1.7.1
  * Allow customizing token JSON encoding
  * Revoke access token if user password is changed
  * Declare support for type checking
  * Many more changes, see CHANGELOG.md
- Drop patch jwt2.patch, included upstream.
* Wed Mar 27 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Wed Mar 31 2021 Markéta Machová <mmachova@suse.com>
- Update to 4.6.0
  * Restored Python 3.7 support
  * Added Indonesian translations
  * Fixed Django 4.0 re_path deprecation
- Add patch jwt2.patch for PyJWT>=2.0.0 support
* Fri Jul 24 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v4.4.0
  * Added official support for Python 3.8 and Django 3.0.
  * Added settings for expected audience and issuer claims.
  * Documentation updates.
  * Updated package/python version support
  * Added Chilean Spanish language support.
  * Added Russian language support.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.3.0:
  * Added JTI_CLAIM setting to allow storing token identifiers under a different claim.
  * We now return HTTP 401 for user not found or inactive.
  * Restricted setup.py config to Python 3 only.
  * Included translation files in release package.
* Tue Apr  9 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v4.1.3
